# Named Entites from Ancora Corpus

## Digital Object Identifier (DOI) and access to dataset files

https://doi.org/10.5281/zenodo.4529299


## Introduction

This is a dataset for Named Eentity Reacognition (NER) from <a href="http://clic.ub.edu/corpus/">Ancora corpus</a> adapted to the conllu format for Machine Learning purposes.

Since multiwords (including Named Entites) in the original Ancora corpus are aggregated as a single lexical item using underscores (e.g. "Ajuntament_de_Barcelona") we splitted them to align with word-per-line .conllu format, and added conventional <a href="https://en.wikipedia.org/wiki/Inside%E2%80%93outside%E2%80%93beginning_(tagging)">Begin-Inside-Outside (IOB) tags</a> to mark and classify Named Entites. We did not filter out the different categories of NEs from Ancora (weak and strong). We did 6 minor edits by hand.

For Licencing reasons, we distribute them in a separate file (with exactly the same length as the original files) to be added to each of the the universal dependencies treebank split files as an eleventh column, so the systems have all rellevant information to learn from, such as POS, Lemma or dependencies labels and relations.

To realign the tags, use the <a href="https://github.com/UniversalDependencies/UD_Catalan-AnCora">UD_Catalan_Ancora Treebank</a> (version 2.7), and apply, for each of the splits, the following command:

<pre>
>> paste ca_ancora-ud-test.conllu ancora_test.NER4conllu > ancora_test.NER4conllu.remapped.conllu
</pre>

### Supported Tasks and Leaderboards

Named Entities Recognition, Language Model

### Languages

CA- Catalan

### Directory structure
 
* ancora_dev.NER4conllu
* ancora_test.NER4conllu
* ancora_train.NER4conllu
* README.txt 

## Dataset Structure

### Data Instances

three one-column files, one for each split.

### Data Fields

Every file has only one column with the IOB tag corresponding to the related token in the conllu files.

### Example:
<pre>
    O
    O
    O
    O
    O
    O
    O
    B-LOC
    O
    O
    B-LOC
    O
    O
    O
    O
    O
    O
    B-MISC
    I-MISC
    O
    B-MISC
    O
</pre>

Result after realigning the tags:

<pre>
16	ja	ja	ADV	ADV	_	18	advmod	_	_	O
17	no	no	ADV	ADV	Polarity=Neg	18	advmod	_	_	O
18	caldrà	caldre	VERB	VERB	Mood=Ind|Number=Sing|Person=3|Tense=Fut|VerbForm=Fin	0	root	_	_	O
19	que	que	SCONJ	SCONJ	_	21	mark	_	_	O
20	es	ell	PRON	PRON	Case=Acc,Dat|Person=3|PrepCase=Npr|PronType=Prs|Reflex=Yes	21	obj	_	_	O
21	desplacin	desplaçar	VERB	VERB	Mood=Sub|Number=Plur|Person=3|Tense=Pres|VerbForm=Fin	18	csubj	_	_	O
22	a	a	ADP	ADP	AdpType=Prep	23	case	_	_	O
23	Tarragona	Tarragona	PROPN	PROPN	_	21	obl	_	_	B-LOC
24	o	o	CCONJ	CCONJ	_	26	cc	_	_	O
25	a	a	ADP	ADP	AdpType=Prep	26	case	_	_	O
26	Vilaseca	Vilaseca	PROPN	PROPN	_	23	conj	_	_	B-LOC
27	per	per	ADP	ADP	AdpType=Prep	28	mark	_	_	O
28	cursar	cursar	VERB	VERB	VerbForm=Inf	21	advcl	_	_	O
29	l'	el	DET	DET	Definite=Def|Number=Sing|PronType=Art	31	det	_	SpaceAfter=No	O
30	últim	últim	ADJ	ADJ	Gender=Masc|Number=Sing|NumType=Ord	31	amod	_	_	O
31	cicle	cicle	NOUN	NOUN	Gender=Masc|Number=Sing	28	obj	_	_	O
32	de	de	ADP	ADP	AdpType=Prep	33	case	_	_	O
33	Grau	Grau	PROPN	PROPN	_	31	nmod	_	MWE=Grau_Mitjà|MWEPOS=PROPN	B-MISC
34	Mitjà	Mitjà	PROPN	PROPN	_	33	flat	_	_	I-MISC
35	de	de	ADP	ADP	AdpType=Prep	36	case	_	_	O
36	Música	Música	PROPN	PROPN	_	31	nmod	_	SpaceAfter=No	B-MISC
37	.	.	PUNCT	PUNCT	PunctType=Peri	18	punct	_	_	O
</pre>

### Data Splits

One for each sub-dataset for train, evaluation and test, as in the Universal Dependencies project.

## Dataset Creation

### Methodology

We adapted the NER labels from Ancora corpus to the conllu format. 
Since multiwords in the original Ancora corpus are aggregated as a single lexical item using underscores (e.g. "Ajuntament_de_Barcelona") we splitted them to align with word-per-line .conllu format, and added conventional <a href="https://en.wikipedia.org/wiki/Inside%E2%80%93outside%E2%80%93beginning_(tagging)">Begin-Inside-Outside (IOB) tags</a> to mark and classify Named Entites. We did not filter out the different categories of NEs from Ancora (weak and strong). We did 6 minor edits by hand.

### Curation Rationale

Following closely CONLLU conventions.

### Source Data

#### Initial Data Collection and Normalization

AnCora consists of a Catalan corpus (AnCora-CA) and a Spanish corpus (AnCora-ES), each of them of 500,000 tokens (some multi-word). The corpora are annotated for linguistic phenomena at different levels.
AnCora corpus is mainly based on newswire texts. For more information, refer to Taulé, M., M.A. Martí, M. Recasens (2009). “AnCora: Multilevel Annotated Corpora for Catalan and Spanish”, Proceedings of 6th International Conference on language Resources and Evaluation. http://www.lrec-conf.org/proceedings/lrec2008/pdf/35_paper.pdf

#### Who are the source language producers?

Catalan Ancora corpus is compiled from articles from the following news outlets: <a href="https://www.efe.com">EFE</a>, <a href="https://www.acn.cat">ACN</a>, <a href="https://www.elperiodico.cat/ca/">El Periodico</a>.

### Annotations

#### Annotation process

We adapted the NER labels from Ancora corpus to the conllu format. 

#### Who are the annotators?

Carlos Rodríguez and Carme Armentano, from BSC-CNS, did the conversion of the labels.

### Dataset Curators

Carlos Rodríguez and Carme Armentano, from BSC-CNS

### Personal and Sensitive Information

No personal or sensitive information included.

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]


## Contact

Carlos Rodríguez-Penagos (carlos.rodriguez1@bsc.es) and Carme Armentano-Oller (carme.armentano@bsc.es)


## License

<a rel="license" href="https://creativecommons.org/licenses/by/4.0/"><img alt="Attribution 4.0 International License" style="border-width:0" src="https://chriszabriskie.com/img/cc-by.png" /></a><br />This work is licensed under a <a rel="license" href="https://creativecommons.org/licenses/by/4.0/">Attribution 4.0 International License</a>.
